//****************************************************************************
// @Module        CAN
// @Filename      CAN.C
// @Project       4_can1.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C164CI-8E
//
// @Compiler      Keil C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the CAN peripheral.
//                
//
//----------------------------------------------------------------------------
// @Date          5/4/00 9:42:03 AM
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"


// USER CODE BEGIN (CAN_General,1)

// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (CAN_General,2)

// USER CODE END


//****************************************************************************
// @Function      void CAN_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the CAN component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the CAN
//                interrupts are to be released, and the priority of the 
//                released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          5/4/00 9:42:03 AM
//
//****************************************************************************

void CAN_vInit(void)
{

  //  ------------ CAN Control/Status Register --------------
  //  start the initialization of the CAN Modul

  BFLD(DP4,0x0020,0x0000);     // set P4.5 (CAN_RxD) to alternate input
                               // P4.6 (CAN_TxD) is set to output by hardware
  BFLD(DP4,0x0040,0x0040);     // set P4.6 (CAN_WxD) to output
                               
  C1CSR  = 0x0041;  // set INIT and CCE

  ///  ------------ Bit Timing Register ---------------------
  /// there are 5 time quanta before sample point
  /// there are 4 time quanta after sample point
  /// the (re)synchronization jump width is 2 time quanta
  /// C1BTR  = 0x6B43;  // set Bit Timing Register  125KB by Gemuendt OK
  /// C1BTR  = 0x6B41;  // set Bit Timing Register  250KB by Gemuendt OK
  /// C1BTR  = 0x1140;  // set Bit Timing Register  500KB by Gemuendt OK
   C1BTR  = 0x1680;  // set Bit Timing Register 1000KB by Gemuendt OK
  
  C1GMS  = 0xE0FF;  // set Global Mask Short Register
//  C1GMS  = 0xFFFF;  // set Global Mask Short Register

  C1UGML = 0xFFFF;  // set Upper Global Mask Long Register

  C1LGML = 0xF8FF;  // set Lower Global Mask Long Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 1 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 1 is not valid
  CAN_OBJ[0].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 2 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 2 is not valid
  CAN_OBJ[1].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 3 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 3 is not valid
  CAN_OBJ[2].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 4 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 4 is not valid
  CAN_OBJ[3].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 5 ---------------------------
  //  ------------------------------------------------------------------------
  /// Message object 5 is valid
 // CAN_OBJ[4].MCR  = 0x5695;    // set Message Control Register
  CAN_OBJ[4].MCR  = 0x5A95;    // set Message Control Register

  /// message direction is transmit
  /// standard 11-bit identifier
  /// 8 valid data bytes
  CAN_OBJ[4].MCFG = 0x0088;      // set Message Configuration Register

  CAN_OBJ[4].UAR  = 0x6024;    // set Upper Arbitration Register
  CAN_OBJ[4].LAR  = 0x0000;    // set Lower Arbitration Register

  CAN_OBJ[4].Data[0] = 0x00;   // set data byte 0
  CAN_OBJ[4].Data[1] = 0x11;   // set data byte 1
  CAN_OBJ[4].Data[2] = 0x22;   // set data byte 2
  CAN_OBJ[4].Data[3] = 0x33;   // set data byte 3
  CAN_OBJ[4].Data[4] = 0x44;   // set data byte 4
  CAN_OBJ[4].Data[5] = 0x55;   // set data byte 5
  CAN_OBJ[4].Data[6] = 0x66;   // set data byte 6
  CAN_OBJ[4].Data[7] = 0x77;   // set data byte 7


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 6 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 6 is not valid
  CAN_OBJ[5].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 7 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 7 is not valid
  CAN_OBJ[6].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 8 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 8 is not valid
  CAN_OBJ[7].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 9 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 9 is not valid
  CAN_OBJ[8].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 10 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 10 is not valid
  CAN_OBJ[9].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 11 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 11 is not valid
  CAN_OBJ[10].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 12 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 12 is not valid
  CAN_OBJ[11].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 13 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 13 is not valid
  CAN_OBJ[12].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 14 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 14 is not valid
  CAN_OBJ[13].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 15 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 15 is not valid
  CAN_OBJ[14].MCR  = 0x5555;    // set Message Control Register



  // USER CODE BEGIN (CAN_Init,0)

  // USER CODE END

  /// ------------ CAN Control/Status Register --------------
  //  reset CCE and INIT
  C1CSR = 0x0000;
  C1IR  = 0x0000;  // set INIT and CCE


  // USER CODE BEGIN (CAN_Init,1)

  // USER CODE END

}


//****************************************************************************
// @Function      void CAN_vTransmit(ubyte ObjNr)
//
//----------------------------------------------------------------------------
// @Description   This function triggers the CAN controller to send the 
//                selected message.
//                If the selected message object is a TRANSMIT OBJECT then 
//                this function triggers the sending of a data frame.
//                If however the selected message object is a RECEIVE OBJECT
//                this function triggers the sending of a remote frame.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    Number of the message object to be sent (1-14)
//
//----------------------------------------------------------------------------
// @Date          5/4/00 9:42:03 AM
//
//****************************************************************************

void CAN_vTransmit(ubyte ObjNr)
{
  CAN_OBJ[ObjNr-1].MCR = 0xe7ff;  // set TXRQ,reset CPUUPD
}




// USER CODE BEGIN (CAN_General,3)

// USER CODE END


